==> vdrdevel-plugin-screenshot_0.0.5.orig.tar.gz: vdrdevel-plugin-screenshot-0.0.5.orig/screenshot.h <==
/*
 * screenshot.h: A plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 */

#ifndef _SCREENSHOT__H
#define _SCREENSHOT__H
 
#include <vdr/plugin.h>
#include <vdr/status.h>
#include "i18n.h"

static const char *VERSION        = "0.0.4";
static const char *DESCRIPTION    = "Takes screenshots";
static const char *MAINMENUENTRY  = "Screenshot";

static const char *FILEFORMATS[10] = {"pnm", "jpg"};

char sPath[100]     = "/tmp";
int  iFileformat    = 1;
int  iQuality       = 95;
int  iNoOfPics      = 1;
int  iHideMenuEntry = false;

class cPluginScreenshot : public cPlugin, public cStatus {
private:
  // Add any member variables or functions you may need here.
  char channelName[30];
  char title[100];
  virtual void Replaying(const cControl *Control, const char *Name);
  virtual void ChannelSwitch(const cDevice *Device, int ChannelNumber);
public:
  cPluginScreenshot(void);
  virtual ~cPluginScreenshot();
  virtual const char *Version(void) { return VERSION; }
  virtual const char *Description(void) { return tr(DESCRIPTION); }
  virtual const char *CommandLineHelp(void);
  virtual bool ProcessArgs(int argc, char *argv[]);
  virtual bool Initialize(void);
  virtual bool Start(void);
  virtual void Housekeeping(void);
  virtual const char *MainMenuEntry(void) { return iHideMenuEntry ? NULL : tr(MAINMENUENTRY); }
  virtual cOsdObject *MainMenuAction(void);
  virtual cMenuSetupPage *SetupMenu(void);
  virtual bool SetupParse(const char *Name, const char *Value);
  };
  
class cMenuSetupScreenshot : public cMenuSetupPage {
private:
  char sNewPath[100];
  int  iNewFileformat;
  int  iNewQuality;
  int  iNewNoOfPics;
  int  iNewHideMenuEntry;
protected:
  virtual void Store(void);
public:
  cMenuSetupScreenshot(void);
};

#endif

==> vdrdevel-plugin-screenshot_0.0.6.orig.tar.gz: vdrdevel-plugin-screenshot-0.0.6.orig/screenshot.h <==
/*
 * screenshot.h: A plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 */

#ifndef _SCREENSHOT__H
#define _SCREENSHOT__H
 
#include <vdr/plugin.h>
#include <vdr/status.h>
#include "i18n.h"

static const char *VERSION        = "0.0.6";
static const char *DESCRIPTION    = "Takes screenshots";
static const char *MAINMENUENTRY  = "Screenshot";

static const char *FILEFORMATS[10] = {"pnm", "jpg"};

char sPath[100]     = "/tmp";
int  iFileformat    = 1;
int  iQuality       = 95;
int  iNoOfPics      = 1;
int  iHideMenuEntry = false;
int  iUserKey       = 0;
int  iHideOsd       = true;

class cPluginScreenshot : public cPlugin, public cStatus {
private:
  // Add any member variables or functions you may need here.
  char title[100];
  virtual void Replaying(const cControl *Control, const char *Name);
//  virtual void ChannelSwitch(const cDevice *Device, int ChannelNumber);
  virtual void OsdProgramme(time_t PresentTime, const char *PresentTitle, const char *PresentSubtitle, time_t FollowingTime, const char *FollowingTitle, const char *FollowingSubtitle);
//  virtual void UserKeyPressed(eKeys Key);
public:
  cPluginScreenshot(void);
  virtual ~cPluginScreenshot();
  virtual const char *Version(void) { return VERSION; }
  virtual const char *Description(void) { return tr(DESCRIPTION); }
  virtual const char *CommandLineHelp(void);
  virtual bool ProcessArgs(int argc, char *argv[]);
  virtual bool Initialize(void);
  virtual bool Start(void);
  virtual void Housekeeping(void);
  virtual const char *MainMenuEntry(void) { return iHideMenuEntry ? NULL : tr(MAINMENUENTRY); }
  virtual cOsdObject *MainMenuAction(void);
  virtual cMenuSetupPage *SetupMenu(void);
  virtual bool SetupParse(const char *Name, const char *Value);
  };
  
class cMenuSetupScreenshot : public cMenuSetupPage {
private:
  char sNewPath[100];
  int  iNewFileformat;
  int  iNewQuality;
  int  iNewNoOfPics;
  int  iNewHideMenuEntry;
  int  iNewUserKey;
  int  iNewHideOsd;
protected:
  virtual void Store(void);
public:
  cMenuSetupScreenshot(void);
};

#endif
